#!/bin/bash

softversion='22.8'
packageversion='62.1'
softname='lilo'
arch='i486'
cpu='i686'

buildir=$(pwd)

srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"

package="$softname-$softversion-$arch-$packageversion"

dest="/tmp/$package"


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
chown -R root:root .
export CFLAGS="-O2 -march=$arch -mcpu=$cpu"

cd $src
make DESTDIR=$dest
make install DESTDIR=$dest

# Description file
mkdir -p $dest/install

cat << "EODESC" > $dest/install/slack-desc
lilo: lilo (Linux Loader)
lilo:
lilo: Generic Boot Loader for Linux ('LInux LOader') by Werner Almesberger.
lilo: LILO boots Linux from your hard drive. It can also boot other
lilo: operating systems such as MS-DOS and OS/2, and can even boot DOS from
lilo: the second hard drive. LILO comes with utilities and documentation
lilo: that make it easier to install, such as 'liloconfig' and 'QuickStart'.
lilo: NOTE: Installing boot loaders is inherently dangerous. Be sure to have
lilo: some means to boot your system from a different media if you install
lilo: LILO on your hard disk.
lilo:
EODESC


mkdir -p $dest/sbin
mkdir -p $dest/boot
mkdir -p $dest/var/log/setup

chmod 755 $buildir/liloconfig $buildir/liloz
cp -pf $buildir/liloconfig $dest/sbin/
cp -pf $buildir/liloz $dest/sbin/lilo

mv /sbin/lilo $dest/sbin/lilo-bin
mv /sbin/mkrescue $dest/sbin/

chmod 644 $buildir/splash.bmp
cp -pf $buildir/splash.bmp $dest/boot/

mkdir -p $dest/usr/doc/$softname-$softversion
cp -a CHANGES COPYING COPYRIGHT INCOMPAT QuickInst READM* doc sample $dest/usr/doc/$softname-$softversion/

mkdir -p $dest/usr/man/man5
mkdir -p $dest/usr/man/man8

mv /usr/man/man5/lilo.conf* $dest/usr/man/man5/
mv /usr/man/man8/lilo.* $dest/usr/man/man8/
mv /usr/man/man8/mkrescue.* $dest/usr/man/man8/

gzip -9 $dest/usr/man/man?/*

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

mkdir -p $dest/usr/src/$softname-$softversion
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

chown -R root:root $dest
cd $dest
makepkg -l y -c n $dest.tgz
rm -rf $dest




